==> vitamui-package-7.1.3-MVN_REPO.tar.gz: fr/gouv/vitamui/collect/common/dto/CollectProjectDto.java <==
/*
 * Copyright French Prime minister Office/SGMAP/DINSIC/Vitam Program (2015-2022)
 *
 * contact.vitam@culture.gouv.fr
 *
 * This software is a computer program whose purpose is to implement a digital archiving back-office system managing
 * high volumetry securely and efficiently.
 *
 * This software is governed by the CeCILL 2.1 license under French law and abiding by the rules of distribution of free
 * software. You can use, modify and/ or redistribute the software under the terms of the CeCILL 2.1 license as
 * circulated by CEA, CNRS and INRIA at the following URL "https://cecill.info".
 *
 * As a counterpart to the access to the source code and rights to copy, modify and redistribute granted by the license,
 * users are provided only with a limited warranty and the software's author, the holder of the economic rights, and the
 * successive licensors have only limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated with loading, using, modifying and/or
 * developing or reproducing the software by the user in light of its specific status of free software, that may mean
 * that it is complicated to manipulate, and that also therefore means that it is reserved for developers and
 * experienced professionals having in-depth computer knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions enabling the security of their systems and/or data
 * to be ensured and, more generally, to use and operate it in the same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had knowledge of the CeCILL 2.1 license and that you
 * accept its terms.
 */
package fr.gouv.vitamui.collect.common.dto;

import com.fasterxml.jackson.annotation.JsonProperty;
import fr.gouv.vitamui.commons.api.domain.IdDto;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;

import java.util.List;

@Data
@AllArgsConstructor
@NoArgsConstructor
@EqualsAndHashCode(callSuper = true)
@Builder
public class CollectProjectDto extends IdDto {

    @JsonProperty("id")
    private String id;

    @JsonProperty("tenant")
    private Integer tenant;

    @JsonProperty("transactionId")
    private String transactionId;

    @JsonProperty("unitUp")
    private String unitUp;

    @JsonProperty("unitUps")
    private List<CollectMetadataUnitUpDto> unitUps;

    private String name;
    private String archivalAgreement;
    private String messageIdentifier;
    private String archivalAgencyIdentifier;
    private String transferringAgencyIdentifier;
    private String originatingAgencyIdentifier;
    private String submissionAgencyIdentifier;
    private String archiveProfile;
    private String comment;
    private String status;
    private String legalStatus;
    private String acquisitionInformation;
    private String createdOn;
    private String lastModifyOn;
    private Boolean automaticIngest;
}

==> vitamui-package-8.1.2-MVN_REPO.tar.gz: fr/gouv/vitamui/collect/common/dto/CollectProjectDto.java <==
/*
 * Copyright French Prime minister Office/SGMAP/DINSIC/Vitam Program (2015-2022)
 *
 * contact.vitam@culture.gouv.fr
 *
 * This software is a computer program whose purpose is to implement a digital archiving back-office system managing
 * high volumetry securely and efficiently.
 *
 * This software is governed by the CeCILL 2.1 license under French law and abiding by the rules of distribution of free
 * software. You can use, modify and/ or redistribute the software under the terms of the CeCILL 2.1 license as
 * circulated by CEA, CNRS and INRIA at the following URL "https://cecill.info".
 *
 * As a counterpart to the access to the source code and rights to copy, modify and redistribute granted by the license,
 * users are provided only with a limited warranty and the software's author, the holder of the economic rights, and the
 * successive licensors have only limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated with loading, using, modifying and/or
 * developing or reproducing the software by the user in light of its specific status of free software, that may mean
 * that it is complicated to manipulate, and that also therefore means that it is reserved for developers and
 * experienced professionals having in-depth computer knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions enabling the security of their systems and/or data
 * to be ensured and, more generally, to use and operate it in the same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had knowledge of the CeCILL 2.1 license and that you
 * accept its terms.
 */
package fr.gouv.vitamui.collect.common.dto;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.annotations.Beta;
import fr.gouv.vitamui.commons.api.domain.IdDto;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;

import java.util.List;

@Data
@AllArgsConstructor
@NoArgsConstructor
@EqualsAndHashCode(callSuper = true)
@Builder
public class CollectProjectDto extends IdDto {

    @JsonProperty("id")
    private String id;

    @JsonProperty("tenant")
    private Integer tenant;

    @JsonProperty("transactionId")
    private String transactionId;

    @JsonProperty("unitUp")
    private String unitUp;

    @JsonProperty("unitUps")
    private List<CollectMetadataUnitUpDto> unitUps;

    // Added transformationRules to support JSLT rules
    @Beta
    @JsonProperty("transformationRules")
    private String transformationRules;

    private String name;
    private String archivalAgreement;
    private String messageIdentifier;
    private String archivalAgencyIdentifier;
    private String transferringAgencyIdentifier;
    private String originatingAgencyIdentifier;
    private String submissionAgencyIdentifier;
    private String archiveProfile;
    private String comment;
    private String status;
    private String legalStatus;
    private String acquisitionInformation;
    private String createdOn;
    private String lastModifyOn;
    private Boolean automaticIngest;
}
